@@ -37,8 +37,9 @@
 #'
 #' @export
 graph.acf <- function(Graphs, plot = TRUE) {
-    if (!valid.input(Graphs, level = 1))
+    if (!valid.input(Graphs, level = 1)) {
         stop("The input should be a list of igraph objects!")
+    }
 
     G.radius <- unlist(Map(f = function(G) {
         get.largest.eigenvalue(G)
